continuation_identity

Function continuation_identity 

pub fn continuation_identity(native_request: &Value) -> String
Settings identity for a stateless continuation. History is supplied in full each time; include/store/reasoning and all other settings remain in the hash. This does not cache or store any conversation on the provider.